package fyloz.trial.ColorRecipesExplorer.web.controller.creators;

import fyloz.trial.ColorRecipesExplorer.model.Company;
import fyloz.trial.ColorRecipesExplorer.services.CompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;

import javax.validation.Valid;

import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.CREATOR_COMPANY;
import static fyloz.trial.ColorRecipesExplorer.web.PagesPaths.CREATOR_COMPANY_SUCCESS;
import static fyloz.trial.ColorRecipesExplorer.web.StringBank.*;

@Controller
public class CompanyCreatorController {

    private CompanyService companyService;

    @Autowired
    public CompanyCreatorController(CompanyService companyService) {
        this.companyService = companyService;
    }

    /**
     * Affiche la page de création d'une bannière.
     *
     * @return La page à afficher.
     */
    @GetMapping(CREATOR_COMPANY)
    public String showCreationPage(Model model, Company company) {
        model.addAttribute("company", company);
        return CREATOR_COMPANY;
    }

    /**
     * Permet à l'utilisateur de créer un bannière.
     * <p>
     * La création échouera si:
     * - L'utilisateur n'est pas autorisé à effectuer cette action
     * - La bannière existe déjà
     * - Une erreur est survenue lors de la sauvegarde dans la base de données
     * <p>
     * Modèle de la page:
     * - error: Contient le message d'erreur, s'il y a lieu
     * - companyName: Contient le nom de la bannière
     * <p>
     * REQUIERT UNE AUTORISATION
     *
     * @param company La bannière à créer
     * @return La page à afficher.
     */
    @PostMapping(value = CREATOR_COMPANY, consumes = MediaType.APPLICATION_FORM_URLENCODED_VALUE)
    public String createCompany(Model model, @ModelAttribute @Valid Company company) {
        if (companyService.isValidForCreation(company)) {
            if ((company = companyService.save(company)) != null) {
                model.addAttribute("companyName", company.getCompanyName());
                return CREATOR_COMPANY_SUCCESS;
            } else {
                model.addAttribute(RESPONSE_ERROR, ERROR_SAVING);
            }
        } else {
            model.addAttribute(RESPONSE_ERROR, String.format(COMPANY_ALREADY_EXIST, company.getCompanyName()));
        }

        return showCreationPage(model, company);
    }
}
